@@ -1,6 +1,7 @@
 import re
 from django.conf import settings
 from django.utils.safestring import mark_safe
+from django.utils.importlib import import_module
 from django.core.paginator import Paginator, EmptyPage
 
 try:
@@ -100,11 +101,17 @@ def check_allow_for_user(request, end_user):
     '''
     if check_allow_impersonate(request):
         # start user can impersonate
-        # Can impersonate anyone who's not a superuser and who is in your
-        # queryset of 'who i can impersonate'
+        # Can impersonate superusers if IMPERSONATE_ALLOW_SUPERUSER is True
+        # Can impersonate anyone who is in your queryset of 'who i can impersonate'.
+        allow_superusers = getattr(
+            settings,
+            'IMPERSONATE_ALLOW_SUPERUSER',
+            False,
+        )
         upk = end_user.pk
         return (
-            not end_user.is_superuser and
+            ((request.user.is_superuser and allow_superusers) or
+                not end_user.is_superuser) and
             users_impersonable(request).filter(pk=upk).exists()
         )
 
@@ -117,12 +124,7 @@ def import_func_from_string(string_name):
         return that function so it can be called
     '''
     mod_name, func_name = string_name.rsplit('.', 1)
-
-    # from http://docs.python.org/faq/programming.html?highlight=importlib#import-x-y-z-returns-module-x-how-do-i-get-z
-    mod = __import__(mod_name)
-    for i in mod_name.split('.')[1:]:
-        mod = getattr(mod, i)
-
+    mod = import_module(mod_name)
     return getattr(mod, func_name)
 
 
